@@ -191,13 +191,15 @@ class TestDecoder(unittest.TestCase):
             self.check_decoding(type, input, expected)
 
     def check_decoding(self, type, input, expected, name=None):
-
         name = name or expected
         db = mmap.mmap(-1, len(input))
         db.write(input)
 
         decoder = Decoder(db, pointer_test=True)
-        (actual, _,) = decoder.decode(0)
+        (
+            actual,
+            _,
+        ) = decoder.decode(0)
 
         if type in ("float", "double"):
             self.assertAlmostEqual(expected, actual, places=3, msg=type)
